use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
APIs
Acklam
Astronomy
Avis
Ben
Brian
Christiansen
Council
David
EXLOCK
Ed
Etheridge
File
Golden
James
Jenness
John
Karen
Keenan
Kevin
Mengue
Mowrey
NFS
Olivier
OpenBSD
POSIX
Particle
Peter
Physics
Rabbitson
Research
Ryde
Steinbrunner
TMPDIR
Temp
Tilly
Tim
TopSystemUID
UK
UNLINK
and
brian
btilly
chdir'ed
cmpstat
dagolden
destructor
dirname
dolmen
dsteinbrunner
eda
endeavour
et
ether
irc
isa
jkeen
lib
newdir
numifies
pjacklam
ribasushi
the
tjenness
unix
unlink
unlinked
unlinking
user42
xdg
